* Files in the directory needed to run the do file: jextzp11.dta, hextzp11.dta (datasets for individuals and households from SILC)
clear
clear matrix
set more off
set memory 500m, permanently

***open dataset for households *** 
***certain variables have the same name in the hh and individual datasets - those in the hh dataset are renamed here with the _hh appendix
use hextzp11
save wsilc11hh, replace
rename dan dan_hh
rename pojis pojis_hh
rename skup skup_hh
rename ea ea_hh
rename hp_vzam hp_vzam_hh
rename hp_vcin hp_vcin_hh
rename rodp rodp_hh
rename nemoc nemoc_hh
rename podp_nez pnezam_hh
rename p_majet p_majet_hh 
rename p_prodej p_prodej_hh
rename p_zivpoj p_zivpoj_hh
rename p_jinpoj p_jinpoj_hh
drop pkoef //it is the same as pkoef in the individual dataset
sort domac
save wsilc11hh, replace

***open dataset for individuals - original dataset merged with additional dataset (from Kalmus)***
* list of additional variables used in taxben: p_majet, p_jine, pnezam, mes_nez, rodp, mes_rod, nemoc, duch_s, duch_v, duch_i, duch_si, mes_duch
use "jextzp11_all.dta", clear
 			
*** save under the working name ***
save taxben, replace 	
***sorting according to household id***
sort domac 															
***merging with the data set for households, each individual receves varaibles for the household he lives in***
capture drop _merge
merge m:1 domac using wsilc11hh
***sorting according to individuals in the household***
sort domac osoba 													

***TAX PARAMETERS*** (loaded from external file)
do etbparameters_c
parameters c

*** NEW0702 General shortcuts for weights
* weight by persons
g rpkoef = round(pkoef)
compress rpkoef
global wep [fw=rpkoef]
* weight by gross incomes
global wei [fw=rpkoef*ginc_i]

* For all that follows, define a lower bound of income that is included in the aggregates etc
scalar inclb = 7999

***INCOMES****

*** Recovering gross business income ***
/*
In SILC, variable pojis is 0 for people with business income. Income for business profit is reported after social security
and health tax contributions have been made (so the reported income is the gross income minus contributions)

We want to recover the gross business income. The issue gets a little complicated because of minimum and maximum
social security contributions.

Here the treatment is for the case when the  (gross income) thresholds for contributions are ordered as
minssed <= minhealthed <= maxssed <= maxhealthed (strict or non-strict inequalities permitted). If the ordering
is changed, the script has to be rewritten.

The important tax system parameters are those valid at the time of data collection (suffix "c" in etbparameters.do)!

The implementation is rather straightforward, just need to find inverse function of a function that gives us
reported income (observed) as a function of gross income (the variable that we want).
*/

*** Need to have months of secondary business - not reported, yet some "realistic" numbers needed for studying the impact of minimum thresholds etc
*** Solution - rank people with secondary business income by that income, assign months proportionately;
*** such that the top 1/12th of the secondary business income distribution has the business for 12 months, next 1/12th for 11 months etc
* divide people into 12-tiles, the numbers of mes_podn_bs is assigned automatically by ascending order

xtile mes_podn_bs = hp_vcin if hp_vcin>0 $wep, nquantiles(12)
replace mes_podn_bs = 0 if mes_podn_bs==.
label var mes_podn_bs "Number of months in secondary business"

* Individual- specific thresholds for self-employed
* The thresholds depend on the number of month when doing business - we construct the individual-specific thresholds
* by deviding the full-year threshold with the number of months when engaged in business

local minbasesed "minssed_bm_c minssed_bs_c minhealthed_c" //minimum depends on the number of months worked
foreach v of local minbasesed {
	g `v'_ind = `v'/(12/(mes_podn+mes_podn_bs)) //division by zero for those who worked 0 months in business -> missing observations
	}
replace minhealthed_c_ind = 0 if (hp_hzam+hp_vzam) > minhealthee_c // set to zero if sufficient employment income

local maxbasesed "maxssed_c maxhealthed_c" //maximum does not depend on the number of months worked
foreach v of local maxbasesed {
	g `v'_ind = `v' 
	}

label variable minssed_bm_c_ind 	"Minimum base for social security (individual) - main business"
label variable minssed_bs_c_ind 	"Minimum base for social security (individual) - main business"
label variable minhealthed_c_ind "Minimum base for health tax (individual)"
label variable maxssed_c_ind 	"Maximum base for social security (individual)"
label variable maxhealthed_c_ind "Maximum base for health tax (individual)"

*** Recovering income from business
* Separate loops for primary and secondary business, but the formulas are the same
local businesstype = "bm bs"
rename hp_podn hp_podn_bm //rename the business income source variables such that one can run the loop
rename hp_vcin hp_podn_bs 
rename mes_podn mes_podn_bm // rename months such that we can run the loop
foreach i of local businesstype {
	//Define kinkpoints in the budget constraint for each individual (the function has different form on each of the intervals)
	g knkpA_`i' = -(ssed_c*minssed_`i'_c_ind + healthed_c*minhealthed_c_ind) 
	//this is reported business income for those with 0 gross (unreported) business income (not necessary because)
	//the slope doesnt change at this point but could be useful
	g knkpB_`i' = knkpA_`i' + (minssed_`i'_c_ind/tbassed_c - 0)*1
	g knkpC_`i' = knkpB_`i' + (minhealthed_c_ind/tbassed_c - minssed_`i'_c_ind/tbassed_c)*(1- tbassed_c * ssed_c)
	g knkpD_`i' = knkpC_`i' + (maxssed_c_ind/tbassed_c - minhealthed_c_ind/tbassed_c)*(1-tbassed_c *(ssed_c + healthed_c))
	g knkpE_`i' = knkpD_`i' + (maxhealthed_c_ind/tbassed_c - maxssed_c_ind/tbassed_c)*(1-tbassed_c *healthed_c)
	label var knkpA_`i' "Individual kinkpoint A on the social security and health insurance schedule for self-employed"

	g ginc_`i' = 0
	//hp_podn: SILC variable. Reported income from main business (insurance already subtracted).
	//We want to recover the true gross income (before insurance paid), this will be svaed in ginc_bm.

	replace ginc_`i' = hp_podn_`i' + ssed_c*minssed_`i'_c_ind + healthed_c*minhealthed_c_ind if hp_podn_`i' <= knkpB_`i' & (mes_podn_`i' > 0)
	//mes_podn > 0 guarantees that we only change this for those who were engaged in business. Can't use hp_podn!=0
	//because there may be people who have zero income from business but have to pay insurance
	//!In 2010 SILC, there were 0 people who had reported income from main business lower than knkpB (4,261) and worked
	//and reported being engaged in the business for at least 1 month (min. income was 10,000)
	replace ginc_`i' = (hp_podn_`i' + healthed_c*minhealthed_c_ind)/(1-ssed_c*tbassed_c)	if hp_podn_`i' > knkpB_`i' & hp_podn_`i' <= knkpC_`i' //in 2010 SILC, nobody fit into this interval
	replace ginc_`i' = hp_podn_`i'/(1-tbassed_c *ssed_c - tbassed_c *healthed_c) 			if hp_podn_`i' > knkpC_`i' & hp_podn_`i' <= knkpD_`i'
	replace ginc_`i' = (hp_podn_`i' + ssed_c*maxssed_c_ind)/(1-tbassed_c *healthed_c)		if hp_podn_`i' > knkpD_`i' & hp_podn_`i' <= knkpE_`i'
	replace ginc_`i' = hp_podn_`i' + ssed_c*maxssed_c_ind + healthed_c*maxhealthed_c_ind 	if hp_podn_`i' > knkpE_`i'
	replace ginc_`i' = 0 if ginc_`i'==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance
}

label var ginc_bm "Gross income from main business"
label var ginc_bs "Gross income from secondary business" 
rename hp_podn_bm hp_podn  //rename back the business income source variables
rename hp_podn_bs hp_vcin
rename mes_podn_bm mes_podn 


*** Isolating labor under formal (full tax) and informal (DPP, reduced tax) contract
* Informal labor - under DPP or no contract and having some positive labor income
g infw   =  (smlouva==3 | smlouva==4) & (hp_hzam>0 | hp_vzam>0)
g ginc_wf = (hp_hzam + hp_vzam)*(1-infw)
g ginc_wi = (hp_hzam + hp_vzam)*(infw)
	
label var infw 		"Dummy for informal labor - DPP or no contract"
label var ginc_wf 	"Gross income from formal work"
label var ginc_wi 	"Gross income from informal work"

*** Defining income from business and from work ***
gen ginc_w	= hp_hzam + hp_vzam
gen ginc_b	= ginc_bm + ginc_bs
gen ginc_i 	= ginc_b + ginc_w
label var ginc_w	"Gross income from work"
label var ginc_b	"Gross income from business"
label var ginc_i	"Gross income (business plus work)"

	* household level total gross income
	bysort domac: egen hhginc_i = total(ginc_i)
	bysort domac: egen hhginc_w = total(ginc_w)
	bysort domac: egen hhginc_b = total(ginc_b)

*** TAKING INCOME TAXES AND SOCIAL/HEALTH INSURANCE AS REPORTED IN SILC, AS OF THE SILC YEAR***
*** COMPUTING THEM BASED ON AVAILABLE INCOME DATA AND TAX RATES WHEN MISSING
*** DEFINING THEM AS ECONOMICALY MEANINGFUL VARIABLES

*** Income tax - 
*** - deduct the bonus from the reported income tax (variable "dan"; the bonus is reported separately
*** - approximate decomposition of income tax into tax paid on work/business income (tax rate is the same on both) ***
*** for that, first define ratio between work and business income***
gen ratio_c	 = (ginc_w*(1+sser_c+healther_c))/(ginc_b+ginc_w*(1+sser_c+healther_c)) if ginc_i > 0 //taxbase for work income = supergross wage
gen inctax_i_c	 = dan-dan_bonus
gen inctax_w_c = ratio_c*inctax_i_c
gen inctax_b_c = (1-ratio_c)*inctax_i_c
replace inctax_w_c = inctax_i if ratio_c == .
replace inctax_b_c = 0 if ratio_c == .
label var ratio_c	"Work income tax base as share of total income tax base"
label var inctax_i_c	"Income tax paid"
label var inctax_w_c	"Income tax paid out of work income"
label var inctax_b_c	"Income tax paid out of business income"

***In what follows, the "p" means "paid" - to distinguish from rates which are named without the p (e.g. ssper_c vs. sser_c)***

*** Imputing the social security / health insurance  ***
/*
***
*** This is not relevant for silc-reported taxes but keep in mind when computing the reform
***taxes paid by employer ***
gen payrolltaxer1 = ginc_w*comins1
label variable payrolltaxer "Composite insurance paid by employer after reform"
*/
*

*** Social security / health insurance paid by employee and employer

* Social security and health insurance paid by employee:
* SILC reports total insurance, we must divide it into ss and health, taking into account the min and max bases

* When above or below the thresholds, the insurances are imputed 

* When the income is below social security minimum, only health insurance is paid (health insurence is equal to total insurance)
* When the income is above social security minimum and below health insurence minimum, employees pay both health and social security insurance (employees pay social security and health insurence derived from their income, on top of that, they pay employee and employer health insurance from difference between minimum of health insurance and their income)
* When the income is between the thresholds, total insurence is divided proportionately by the marginal contribution rates
* When the income is above social security maximum and below health insurence maximum, , employees pay social security insurence from the treshold and health insusence from the income  
* When the income is above both the thresholds (social security and health insurance), employees pay social security insurance from the social security treshold and health insusence from health insurance treshold
* The algorithm works under 2011 ordering of tresholds (it is prepared for ordering effective at least till 2014, when maximum of social security is lower than health maximum) 

local minbasesee "minssee_c minhealthee_c" //minimum depends on the number of months worked
foreach v of local minbasesee {
	g `v'_ind = `v'/(12/mes_zam) //division by zero for those who worked 0 months in business -> missing observations
	}
local maxbasesee "maxssee_c maxhealthee_c" //maximum does not depend on the number of months worked
foreach v of local maxbasesee {
	g `v'_ind = `v'
	}

gen     healthpee_c = pojis					 	 if ginc_wf< minssee_c_ind & ginc_wf >0 
gen     sspee_c     = 0 						 if ginc_wf< minssee_c_ind & ginc_wf >0 

replace healthpee_c = ginc_wf*healthee_c + (minhealthee_c_ind-ginc_wf)*(healthee_c+healther_c) 	 if ginc_wf>= minssee_c_ind & ginc_wf< minhealthee_c_ind
replace sspee_c     = pojis - healthpee_c				 						 if ginc_wf>= minssee_c_ind & ginc_wf< minhealthee_c_ind

replace healthpee_c = pojis*(healthee_c/(ssee_c+healthee_c)) if ginc_wf>= minhealthee_c_ind & ginc_wf< maxssee_c_ind
replace sspee_c     = pojis*(ssee_c    /(ssee_c+healthee_c)) if ginc_wf>= minhealthee_c_ind & ginc_wf< maxssee_c_ind

replace sspee_c     = maxssee_c_ind*ssee_c			 if ginc_wf>= maxssee_c_ind & ginc_wf< maxhealthee_c_ind
replace healthpee_c = pojis - sspee_c				 if ginc_wf>= maxssee_c_ind & ginc_wf< maxhealthee_c_ind

replace healthpee_c = healthee_c*maxhealthee_c_ind	 if ginc_wf>= maxhealthee_c_ind
replace sspee_c     = ssee_c    *maxssee_c_ind  	 if ginc_wf>= maxhealthee_c_ind

replace healthpee_c = 0 if healthpee_c ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
replace sspee_c     = 0 if sspee_c ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

label var sspee_c	 "Social security insurance paid by employee"
label var healthpee_c "Social security insurance paid by employee"

* Social security and health insurance paid by employer:
* SILC does not report, we impute it by the same formula used in compute.do
* (taking into account floors and caps, distringuishing formal and informal work)
* Formal work: linear tax rate, minimal income for social security participation, max cap for both

local minbaseser "minsser_c" //minimum depends on the number of months worked
foreach v of local minbaseser {
	g `v'_ind = `v'/(12/mes_zam) //division by zero for those who worked 0 months in business -> missing observations
	}
local maxbaseser "maxsser_c maxhealther_c" //maximum does not depend on the number of months worked
foreach v of local maxbaseser {
	g `v'_ind = `v'
	}

g       ssper_wf_c = 0			   			  	if ginc_wf < minsser_c_ind  & ginc_wf >0 
replace ssper_wf_c = sser_c * ginc_wf   	  	if ginc_wf >= minsser_c_ind & ginc_wf < maxsser_c_ind 
replace ssper_wf_c = sser_c * maxsser_c_ind 	if ginc_wf >= maxsser_c_ind

g healthper_wf_c = healther_c * ginc_wf
replace healthper_wf_c = healther_c * maxhealther_c if ginc_wf > maxhealther_c_ind

replace healthper_wf_c = 0 if healthper_wf_c ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
replace ssper_wf_c     = 0 if ssper_wf_c ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

label variable ssper_wf_c "Social security insurance paid by employer, formal work"
label variable healthper_wf_c "Health insurance paid by employer, formal work"
	
* Informal work: linear tax rate on income exceeding the annual exemption limit 
g ssper_wi_c = 0
replace ssper_wi_c = sser_c*(ginc_wi-maxiw_c) if ginc_wi > maxiw_c
g healthper_wi_c = 0 
replace healthper_wi_c = healther_c*(ginc_wi-maxiw_c) if ginc_wi>maxiw_c
label variable ssper_wi_c "Social security insurance paid by employer, informal work"
label variable healthper_wi_c "Health insurance paid by employer, informal work"
*** This could be extended to allow some positive tax rate below the limit and set current rates to zero

* Payroll taxes by the self-employed
*** SILC does not report directly
*** We impute it by the inverse of the algorithm for recovering business income 
*** Distinguishing main and secondary business income - assume that floors apply to main but not secondary income

* Loop over main and secondary business incomes
local businesstype = "bm bs" 
foreach i of local businesstype {
	**Social security (apply individual thresholds)
	gen ssped_`i'_c 	= tbassed_c *ssed_c *ginc_`i'
	replace ssped_`i'_c = ssed_c*minssed_`i'_c_ind 	if tbassed_c *ginc_`i' < minssed_`i'_c_ind & ginc_`i' > 0
	replace ssped_`i'_c = ssed_c*maxssed_c_ind 		if tbassed_c *ginc_`i' > maxssed_c_ind
	/*
	In the case of lower threshold, checked whether ginc_`i'!=0 so that the minimum insurance assigned only
	to those who had some income from main business. 
	There were 0 observations in 2010 sample with negative ginc_bm.
	*/
	replace ssped_`i'_c = 0 if ssped_`i'_c ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)

	**Health insurance (apply individual thresholds)
	gen healthped_`i'_c 	= tbassed_c* healthed_c*ginc_`i'
	replace healthped_`i'_c = healthed_c*minhealthed_c_ind if tbassed_c* ginc_`i' < minhealthed_c_ind & ginc_`i' >0
	replace healthped_`i'_c = healthed_c*maxhealthed_c_ind if tbassed_c* ginc_`i' > maxhealthed_c_ind
	replace healthped_`i'_c = 0 if healthped_`i'_c ==. // missings can make a problem afterward in summation of incomes, healh, social security and total insurance (missings come from minimum definition)
}
label var ssped_bm_c 		"Social security contribution paid on main business income"
label var ssped_bs_c 		"Social security contribution paid on secondary business income"
label var healthped_bm_c	"Health insurance paid on main business income"
label var healthped_bs_c 	"Health insurance paid on secondary business income"

* Suming the payroll taxes 

* By revenue source and business/work income
gen ssp_w_c 	= sspee_c + ssper_wf_c + ssper_wi_c
gen ssp_b_c 	= ssped_bm_c + ssped_bs_c
gen ssp_i_c 	= ssp_w_c + ssp_b_c

gen healthp_w_c = healthpee_c + healthper_wf_c + healthper_wi_c
gen healthp_b_c = healthped_bm_c + healthped_bs_c
gen healthp_i_c = healthp_w_c + healthp_b_c

label var ssp_w_c 	"Social security contributions on work income" 
label var ssp_b_c 	"Social security contributions on business income" 
label var ssp_i_c 	"Social security contributions on all income (work and business)" 
label var healthp_w_c	"Health contributions on work income" 
label var healthp_b_c	"Health contributions on business income"
label var healthp_i_c 	"Health contributions on all income (work and business)" 

* Payroll tax by employee/employer/self_employed
gen		payrolltaxee_c = sspee_c + healthpee_c 
gen		payrolltaxer_c = ssper_wf_c + ssper_wi_c + healthper_wf_c + healthper_wi_c
gen 	payrolltax_w_c  = sspee_c + healthpee_c+ssper_wf_c + ssper_wi_c + healthper_wf_c + healthper_wi_c
label var payrolltaxee_c	"Payroll taxes (health + social security) paid by employee"
label var payrolltaxer_c	"Payroll taxes (health + social security) paid by employer"
label var payrolltax_w_c	"All payroll taxes on work income (by employer and employee)"

gen 	payrolltax_b_c 		= 0
gen 	payrolltaxed_bm_c	= 0
gen 	payrolltaxed_bs_c 	= 0
replace payrolltaxed_bm_c 	= ssped_bm_c + healthped_bm_c
replace payrolltaxed_bs_c 	= ssped_bs_c + healthped_bs_c
replace payrolltax_b_c 		= payrolltaxed_bm_c + payrolltaxed_bs_c

label var payrolltax_b_c	"All payroll taxes paid on business income"
label var payrolltaxed_bm_c	"Payroll taxes paid on main business income"
label var payrolltaxed_bs_c	"Payroll taxes paid on secondary business income"

* Payroll tax on all income
generate payrolltax_i_c = payrolltax_w_c + payrolltax_b_c
label variable payrolltax_i_c "Total payroll tax on all income(work and business)"

*** Economic concept of income (supergross) ****
gen sginc_w_c = ginc_w + payrolltaxer_c
gen sginc_b_c = ginc_b
gen sginc_i_c = sginc_w_c + sginc_b_c
label var sginc_w_c	"Super gross work income from work"
label var sginc_b_c	"Super gross business income"
label var sginc_i_c	"Total supergross income"

*** shares of income sources ****
gen shr_wi_ginc_w = ginc_wi/ginc_w
gen shr_wf_ginc_w = ginc_wf/ginc_w
gen shr_bm_ginc_b = ginc_bm/ginc_b
gen shr_bs_ginc_b = ginc_bs/ginc_b
gen shr_w_ginc_i  = ginc_w/ginc_i
gen shr_b_ginc_i   = ginc_b/ginc_i
* for those with zero income, fill in national aggregates
* for informal work not that importat - very small share on average, those with positive have informal share equal to one
capture program drop shr_replace
program define shr_replace
	args shr denom
	sum `shr' if `denom' > 0 $wep 
	replace `shr' = r(mean) if `shr' == . 
end
shr_replace shr_wi_ginc_w ginc_w
shr_replace shr_wf_ginc_w ginc_w
shr_replace shr_bm_ginc_b ginc_b
shr_replace shr_bs_ginc_b ginc_b
shr_replace shr_w_ginc_i ginc_i
shr_replace shr_b_ginc_i ginc_i

label var shr_wi_ginc_w "share of informal work income in gross work income"
label var shr_wf_ginc_w "share of formal work income in gross work income"
label var shr_bm_ginc_b "share of main business income in gross business income"
label var shr_bs_ginc_b "share of secondary business income in gross business income"
label var shr_w_ginc_i  "share of work income in total gross income"
label var shr_b_ginc_i   "share of business income in total gross income"

* Total taxes on income (income tax plus payroll - hence not including social benefits and consumption taxes)
gen totaltax_w_c 		= inctax_w_c + payrolltax_w_c
gen totaltax_b_c 		= inctax_b_c + payrolltax_b_c
gen totaltax_i_c		= totaltax_w_c + totaltax_b_c
label var totaltax_b_c 	"Total taxes on business income, c"
label var totaltax_w_c 	"Total taxes on work income, c"
label var totaltax_i_c	"Total taxes on work and business incomes, c"
	
	*** Taxes summed at the hh level
	foreach v of varlist totaltax_w_c totaltax_b_c totaltax_i_c {
		bysort domac: egen hh`v' = total(`v')
	}
	label var hhtotaltax_i_c  "Total household taxes on work and business income, c"
	
*** GENERATING TAX UNITS

gen assigned = 0 //dummy variable indicating whether we already assigned an individual to some tax unit
label variable assigned "Temporary dummy variable = 0 if an individual has not been assigned to a tax unit"

gen taxunit = ""
label variable taxunit "ID of tax unit (household ID plus number of tax unit)"

gen domacstr = string(domac,"%11.0g") //we need household ID as a string

by domac: egen members = count(osoba) //number of members of a household (fixed throughout)
by domac: egen membersassigned = total(assigned) //number of household members already assigned to a tax unit
gen membersassignedold = membersassigned
drop membersassigned
 //for every household, the number of unassigned members before a change was made.
//We use this to track whether someone from the household was assigned a tax unit after some criteria applied

/* program increase ID
- run this everytime someone might have been assigned to some tax unit from a household (when assigned changes)
If the number of people in the household that are assigned to a tax unit changed, the ID variable
next ID which stores the ID given to the next tak unit formed from the household increases.
*/ 
capture program drop increaseid
program define increaseid

by domac: egen membersassigned = total(assigned) //number of household members already assigned to a tax unit
replace nextid = nextid + 1 if membersassignedold ~= membersassigned //if the number different, household's next tax unit ID increases
replace membersassignedold = membersassigned
drop membersassigned

tabulate nextid //just for debug purposes
end

gen TUpair = .
label variable TUpair "Equals 1 if the individual is a member of married pair on top of tax unit"
//this is needed for calculating spouse benefits
//one or both of them are eligible for tax exemption provided that the income of the other is sufficiently low
//we define this only for tax units which are headed by a married pair (vztah (1,2),(3,4) or (6,6))

gen nextid = 1 //next id to be used for tax unit. TU IDs are generated as ID of household + ID of tax unit in the household
//when a tax unit withing a household is formed, this variable is incremented by one

/*
We generate dummy varaible nezaop. It equals 1 if a person is younger than 18 or is a full-time student younger than 26 years.
If a person satisfies these criteria, someone can be aligible for child tax exemption. More precisely, 
35c of income tax law sets the conditions for eligibility. We do not check the health conditoins, because 
we do not have sufficiently detailed data.


(6) Za vyivovan dt poplatnka se pro ely tohoto zkona povauje dt vlastn, osvojen, dt v pi, kter nahrazuje pi rodi, dt druhho z manel a vnuk (vnuka), pokud jeho (jej) rodie nemaj pjmy, z nich by mohli daov zvhodnn uplatnit, pokud je
a) nezletilm dttem,
b) zletilm dttem a do dovren vku 26 let, jestlie nepobr invalidn dchod pro invaliditu tetho stupn a
1. soustavn se pipravuje na budouc povoln; pprava na budouc povoln se posuzuje podle zkona o sttn sociln podpoe,14d)
2. neme se soustavn pipravovat na budouc povoln nebo vykonvat vdlenou innost pro nemoc nebo raz, nebo
3. z dvodu dlouhodob nepznivho zdravotnho stavu je neschopno vykonvat soustavnou vdlenou innost.
*/

gen nezaop = 0 //nezaop, not vyziv. Because not all people who satisfy the criteria are 'vyzivovane' by someone.
label variable nezaop "Dummy variable. Equals 1 if the person is not older than 18 years or 26 years and a student."
replace nezaop = 1 if (vek<18) | (vek<26 & ea==6) //ea=6 means that the person is a student (daily study)

/*
Logical structure

Our goal is to have married partners and their children in one tax unit.
However, only children who are young or students (nezaop=1) should be assigned to a tax unit with their parents.

Because of the structure of data, where all information about relations is centered around household head
(variable vztah), we begin with the household head, his spouse, and their children.

We deal with those left unassigned in the next stages.


(1) Household head, his spouse, and children
First, distinguish 3 cases, summarized by variable spousehh

spousehh
=0 if there is no spouse of the household head in the household
=1 if there is a spouse of the household head present, but not married to the household head
=2 if there is a spouse of the household head present, married to the household head

Here, as well as in the rest of the part which defines tax units, suffix "hh" means that the variable
refers to the household (even though every individual has a value)

The following part generates this variable (spousehh)
*/

gen spouse = 0
label variable spouse "Dummy, equals 1 if the person is a spouse of household head."
replace spouse = 1 if vztah == 2
by domac: egen spousehh = max(spouse)
label variable spousehh "Equals 0 if there is no spouse of the household head in the household, 1 if there is spouse but unmarried, 2 if there is a married spouse."
//note: at this stage, spousehh = 1 if there is a spouse in the household head, married or not. It is replaced later on.

// Now, we want to find out whether the household head is married to his spouse

gen marriedhead=1 if (vztah==1 & stav == 2)
by domac: egen marriedheadhh = max(marriedhead) //equals 1 for everyone in the household if household head married
gen marriedspouse=1 if (vztah==2 & stav == 2)
by domac: egen marriedspousehh = max(marriedspouse)
//we assume that if household head and his spouse are married, they are married to each other. Then spousehh=2
replace spousehh = 2 if marriedheadhh == 1 & marriedspousehh == 1 

//Now that we have determined spousehh, we solve the 3 cases individually"

//At this stage, we assign only children that have been declared to belong to the household head (vztah == 3)
*** (a) single household head (no partner, not even unmarried) ***
//we assign the head and all his children that are 'vyzivovane' to the first tax unit.
replace taxunit = domacstr+string(nextid) if spousehh == 0 & (vztah==1 | (vztah==3&nezaop==1))
replace assigned = assigned+1 if spousehh == 0 & (vztah==1 | (vztah==3&nezaop==1))
increaseid

*** (b) household head living with spouse, but not married to each other ***
//first form a tax unit of household head and his children
replace taxunit = domacstr+string(nextid) if spousehh == 1 & (vztah==1 | (vztah==3&nezaop==1))
replace assigned = assigned+1 if spousehh == 1 & (vztah==1 | (vztah==3&nezaop==1))
increaseid

/*
If the spouse of the household head has children in the household (rodic=1) and the children have vztah=8 (other
of household head), we form another tax unit with the spouse as head and the remaining children. 

Technically, these could belong to someone else in the family but we have no way to tell due to limited data quality.
If the spouse has no kids, we form a tax unit with just her.
*/
//determining whether the spouse of household head has a child living in the household:
generate spouseparenttmp = 0
replace spouseparenttmp = 1 if vztah == 2 & rodic == 1
by domac: egen spouseparent = max(spouseparenttmp)
label variable spouseparent "Dummy variable. Equals 1 for all members of a household if the spouse of household head has a child living in the household"
drop spouseparenttmp

//forming tax units where spouse of household head is alone (because she has no child in the family)
replace taxunit = domacstr+string(nextid) if spousehh == 1 & vztah==2 & spouseparent == 0
replace assigned = assigned+1 if spousehh == 1 & vztah==2 & spouseparent == 0
increaseid

//forming tax units headed by the spouse of household head, where all remaining unassigned children are assigned to her
replace taxunit = domacstr+string(nextid) if spousehh == 1 & spouseparent == 1 & (vztah==2 | (nezaop==1&assigned==0&vztah==8))
replace assigned = assigned+1 if spousehh == 1 & spouseparent == 1 & (vztah==2 | (nezaop==1&assigned==0&vztah==8))
increaseid
//note: at this stage, assigned == 0 is equivalent to vztah~=3 for the children


*** (c) household head living with spouse, married to each other ***
//in this case, we also assign the spouse to the same tax unit
replace taxunit = domacstr+string(nextid) if spousehh == 2 & (vztah==1 | vztah==2 | (vztah==3&nezaop==1))
replace assigned = assigned+1 if spousehh == 2 & (vztah==1 | vztah==2 | (vztah==3&nezaop==1))
increaseid

replace TUpair = 1 if spousehh == 2 & (vztah==1 | vztah==2)
/*note: 
What about children who don't have vztah = 3? In the data (SILC 2010), there are 89 such children, only 1 of which
has vztah = 8, and 82 have vztah = 5 (grandchild of household head). So it is reasonable to leave them unassigned
for now (most likely we will want to assign them to a tax unit headed by children of household head)
Only if we fail to assign these children to such tax units, we consider assigning them to household head/spouse.

Vztah refers to legal relation, not biological. So if they are married and vztah is not 3, then the person
is not a child of either of the two partners (head or spouse). 
*/

/*
(2) Forming tax units of next-generation couples (son/daughter of household head and his/her partner) and their children

We adopt 2 reasonable assumptions:
(i) If there is exactly one married person with vztah=3 (son/daughter) and exactly one married with vztah=4 
(son-in-law/daughter-in-law), they are married to each other (thus fall into the same tax unit)
(ii)
Even though we cannot tell for sure that the unassigned children belong to such a couple, we assume that if
the both in the couple are parents, then the children belong to them.
*/

//first, generate useful dummies
//problematic: What if there are households with multiple sons/daughter and more sons/daughters in law
//not really, there are only 15 households (out of cca 9000) in which there is a son/daughter parent AND son/daughter in law parent


//because there is a possible issue of multiple sons/daughters, I now use count combined with missing observations as opposed to 0/1 and max() as before
gen sondaughter = 1 if vztah == 3
by domac: egen sondaughterhh = count(sondaughter)
label variable sondaughterhh "Number of sons/daughters of the household head in the household."

gen sondaughterparent = 1 if vztah == 3 & rodic == 1
by domac: egen sondaughterparenthh = count(sondaughterparent)
label variable sondaughterparenthh "Number of sons/daughters of the household head who have a child living in the household"

gen sondaughtermarried = 1 if vztah == 3 & stav == 2
by domac: egen sondaughtermarriedhh = count(sondaughtermarried)
label variable sondaughtermarriedhh "Number of sons/daughters of the household head who are married"

/*
We need the following variable to check for the case when there is exactly one married son/daughter
and exactly one married son/daughter in law, but they might not be parents (there could be unmarried
son/daughter (in law) who are parents)
*/
gen sondaughtermarriedparent = 1 if vztah == 3 & stav == 2 & rodic == 1
by domac: egen sondaughtermarriedparenthh = count(sondaughtermarriedparent)
label variable sondaughtermarriedparenthh "Number of married sons/daughters of the household head who have a child living in the household"


gen sondaughterIL = 1 if vztah == 4
by domac: egen sondaughterILhh = count(sondaughterIL)
label variable sondaughterILhh "Number of sons/daughters in law of the household head in the household."

gen sondaughterILparent = 1 if vztah == 4 & rodic == 1
by domac: egen sondaughterILparenthh = count(sondaughterILparent)
label variable sondaughterILparenthh "Number of sons/daughters in law of the household head who have a child living in the household"

gen sondaughterILmarried = 1 if vztah == 4 & stav == 2
by domac: egen sondaughterILmarriedhh = count(sondaughterILmarried)
label variable sondaughterILmarriedhh "Number of sons/daughters in law of the household head who are married"

gen sondaughterILmarriedparent = 1 if vztah == 4 & stav == 2 & rodic == 1
by domac: egen sondaughterILmarriedparenthh = count(sondaughterILmarriedparent)
label variable sondaughterILmarriedparenthh "Number of married sons/daughters in law of the household head who have a child living in the household"


//Checking the cases where there is a married son/daughter, married son/daughter in law, and there is more than 1 of either of them
//in all other cases, we have on problem, because they would not be assigned to the same tax unit anyway
tabulate sondaughtermarriedhh
tabulate sondaughtermarriedhh
//we can see that there is always at most 1 son/daughter and 1 son/daughter in law who are married -> no problems

/*(a) The case when there is EXACTLY one son/daughter and exactly one son/daughter in law who are both married
Then they form a tax unit, 

If there is more than one of either (married son/daughter or married son/daughter in law) in the household,
we do not put them into one tax unit

*/
//(i) When the couple has no children (neither of the two has a child), only the couple forms a tax unit
replace taxunit = domacstr+string(nextid) if  assigned==0 & (sondaughtermarriedhh==1 & sondaughterILmarriedhh==1) & (sondaughtermarriedparenthh==0 & sondaughterILmarriedparenthh==0) & (sondaughtermarried==1 | sondaughterILmarried==1)
replace assigned = assigned+1 if  assigned==0 & (sondaughtermarriedhh==1 & sondaughterILmarriedhh==1) & (sondaughtermarriedparenthh==0 & sondaughterILmarriedparenthh==0) & (sondaughtermarried==1 | sondaughterILmarried==1)
increaseid

//(ii) When either of the couple has children, we assign all the children left unassigned to this couple
replace taxunit = domacstr+string(nextid) if  assigned==0 & (sondaughtermarriedhh==1 & sondaughterILmarriedhh==1) & (sondaughtermarriedparenthh==1 | sondaughterILmarriedparenthh==1) & (sondaughtermarried==1 | sondaughterILmarried==1 | nezaop==1)
replace assigned = assigned+1 if  assigned==0 & (sondaughtermarriedhh==1 & sondaughterILmarriedhh==1) & (sondaughtermarriedparenthh==1 | sondaughterILmarriedparenthh==1) & (sondaughtermarried==1 | sondaughterILmarried==1 | nezaop==1)
increaseid

//in this case, there is a married couple on top of the tax unit, and we store this information in the following dummy
replace TUpair = 1 if  assigned==0 & (sondaughtermarriedhh==1 & sondaughterILmarriedhh==1) & (sondaughtermarried==1 | sondaughterILmarried==1) 
/*
(b) When case (a) does not occur, we do not put any sons/daughters and sons/daughters in law to a tax unit

(i) When there is exactly one son/daughter who is parent, we assign the remaining unassigned children to her.
(There were 6 observations where there were multiple sons/daughters who are parents - in this case, we do not
assign the children to any of sons/daughters at this stage)

(ii) When there is exactly one son/daughter in law who is parent, we assign the remaining unassigned children to her.

In other cases, we leave the children unassigned for now. (Such as when there are multiple sons/daughter
or sons/daughters in law who are parents)
*/

//(i)
replace taxunit = domacstr+string(nextid) if assigned==0 & sondaughterparenthh==1 & (sondaughterparent==1 | nezaop==1)
replace assigned = assigned+1 if assigned==0 & sondaughterparenthh==1 & (sondaughterparent==1 | nezaop==1)
increaseid

//(ii) The same for sons/daughter in law who are parents
replace taxunit = domacstr+string(nextid) if assigned==0 & sondaughterILparenthh==1 & (sondaughterILparent==1 | nezaop==1)
replace assigned = assigned+1 if assigned==0 & sondaughterILparenthh==1 & (sondaughterILparent==1 | nezaop==1)
increaseid

*** what remains: Make pairs out of fathers/mothers fathers/mothers in law (6)
///assigne everyone who remains to her own tax unit if not nezaop
///find heads of tax units (the one with the highest income)
//assign all nezaops to the tax unit in domac with the highest income
///whoever remains - nezaop children unassigned anywhere else (probably alone), assign him to her own tax unit (he will be the head of the tax unit)

/*
(3) Forming tax units of parents/parents in law (of household head)

If there are two people with vztah=6 and stav=2, we assume that they are married to each other and they form
a tax unit. If there are more than two (which does not happen a single time in 2010 dataset),
we do not solve the case and let them form separate tax units.

We do not assign any children to them. Even though in theory, some children could be associated with them,
we do not have enough data to establish this firmly, and it is more likely that the unassigned children
belong to someone else.
*/
gen parentmarried = 1 if vztah == 6 & stav == 2
by domac: egen parentmarriedhh = count(parentmarried)
label variable parentmarriedhh "Number of married fathers/mothers or fathers/mathers in law of the household head"

replace taxunit = domacstr+string(nextid) if assigned==0 & parentmarriedhh==2 & parentmarried==1 
//if there are 2 married parents/parents-in-law and the person is one of them, we put him into the tax unit
replace assigned = assigned+1 if assigned==0 & parentmarriedhh==2 & parentmarried==1
increaseid

replace TUpair = 1 if assigned==0 & parentmarriedhh==2 & parentmarried==1 //for each of the pair, store that he is a part of the pair heading a tax unit

/*
At this stage, we have formed couples and assigned children (under 18 or students) to them, where it
was reasonable to assign them. Now we form one-member tax units from the remaining people who are not
children (nezaop=0). Then, we find tax heads of these tax units (the person with highest income).
Then, we assign the remainder of nezaop children to these tax units (the one whose hed has highest income).
In 2010 dataset, there were only 51 children left to be assigned this way.
*/

//(4) Forming single-member tax units from those who are not assigned to other tax units and are not children (nezaop=0)

by domac: egen IDtmp = rank(osoba) if assigned == 0 & nezaop==0 //we generate ID of tax unit for unassigned people who are not nezaop
replace IDtmp = 0 if IDtmp==. //replace missing observations with zeros
//we use that osoba is a personal ID unique in every household
by domac: egen numberofunassigned = max(IDtmp)

//now nextid is incremented by ID of unassigned person (1 subtracted so we don't skip an ID)
replace taxunit = domacstr+string(nextid-1+IDtmp) if assigned == 0 & nezaop==0
replace assigned = assigned+1 if assigned == 0 & nezaop==0
replace nextid = nextid + numberofunassigned //increment next ID for a household by the number of tax units generated at this stage

//(5) Finding tax heads of the tax units - the member with the highest income

//To begin with, define a dummy householdhead, equals 0.01 if the person is household head
//We use this to make sure that if two people in a tax unit have the same income and one of them is household head,
//the household head becomes the head of tax unit for tax purposes. We do this because the fact that someone was
//marked as a household head carries some information.

gen householdhead = 0
replace householdhead = 0.01 if vztah ==1

gsort taxunit -ginc_i
by taxunit: egen taxhead=rank(-(ginc_i+householdhead)) if taxunit ~= "" ,unique  //taxunit = ""... those still unassigned
//rank - use unique - breaks ties arbitrarily. But if a person is a household head, his income is larger by 0.01 for
//sorting purpose. It makes a difference when there are 2 people within a household head with the same income
//and one of them is household head. In all other cases, it makes no difference, because income is given in whole numbers.

replace taxhead = 0 if taxhead > 1 //if not the highest income in the tax unit, replace with 0
label variable taxhead "Dummy, equal to 1 if the person is tax head of a tax unit, 0 otherwise"

//(6) Assigning the remaining nezaop children to the tax unit within their household whose tax head has the highest income
//This is a little confusing at first sight, maybe not efficient, but correct
generate taxheadincome = ginc_i * taxhead //= ginc_i for heads of tax units, 0 for everyone else (or heads with 0 income)

replace taxheadincome = . if taxunit == "" //to prevent problems when nobody in the family has any income
//this guarantees that the people not placed in any tax unit will never come on top of rank 
//(a marginal issue, would cause 7 observations to be placed wrongly in the 2010 dataset)
gsort domac -taxheadincome
by domac: egen HHtaxhead = rank(-(taxheadincome+householdhead)) ,unique
drop taxheadincome
 
replace HHtaxhead = 0 if HHtaxhead ~= 1 //dummy, 1 if a person is the richest tax head in a household. We actually want to save this result
//for later use
label variable HHtaxhead "Dummy, equals 1 if the person is the richest tax head in household, 0 otherwise"
generate richesttaxheadtaxunit = taxunit if HHtaxhead == 1
destring richesttaxheadtaxunit ,replace //we destring only so that we can use max in egen
format richesttaxheadtaxunit %12.0g
by domac: egen double richesttaxheadtaxunithh = max(richesttaxheadtaxunit)
format richesttaxheadtaxunithh %12.0g
gen richesttaxheadtaxunithhstr = string(richesttaxheadtaxunithh,"%12.0g")
//variable richesttaxheadtaxunithhstr is a string type, for every individual, it contains the ID of tax unit
//headed by the richest tax head (so headed by the richest individual, unless he is a nezaop child)

//now we simply assign the remaining nezaop children to the appropriate tax unit
replace taxunit = richesttaxheadtaxunithhstr if assigned == 0 & nezaop==1 & richesttaxheadtaxunithh~=.
replace assigned = assigned + 1 if assigned == 0 & nezaop==1 & richesttaxheadtaxunithh~=.

//This concludes assigning prople to tax units

*** Checking what share is assigned (plus shouldn't have a value other than 0 or 1) ***
tabulate assigned


*** GENERATING BEN UNIT FOR CHILD ALLOWANCE

gen assignedb = 0 //dummy variable indicating whether we already assigned an individual to some ben unit
label variable assignedb "Temporary dummy variable = 0 if an individual has not been assigned to a ben unit"

gen benunit = ""
label variable benunit "ID of ben unit (household ID plus number of ben unit)"

by domac: egen membersassignedb = total(assignedb) //number of household members already assigned to a ben unit
gen membersassignedbold = membersassignedb
drop membersassignedb
//for every household, the number of unassigned members before a change was made.
//We use this to track whether someone from the household was assigned a ben unit after some criteria applied

/* program increase ID b
- run this everytime someone might have been assigned to some ben unit from a household (when assigned changes)
If the number of people in the household that are assigned to a ben unit changed, the ID variable
next ID which stores the ID given to the next ben unit formed from the household increases.
*/ 
capture program drop increaseidb
program define increaseidb

by domac: egen membersassignedb = total(assignedb) //number of household members already assigned to a ben unit
replace nextidb = nextidb + 1 if membersassignedbold ~= membersassignedb //if the number different, household's next ben unit ID increases
replace membersassignedbold = membersassignedb
drop membersassignedb

tabulate nextidb //just for debug purposes
end

gen nextidb = 1 //next id to be used for ben unit. TU IDs are generated as ID of household + ID of ben unit in the household
//when a ben unit withing a household is formed, this variable is incremented by one


/* We generate dummy varaible nezaopb - a concept of nezaop children for benefit calculation purposes. 
It is a bit different than nezaop (concept of nezaop children for tax purposes).
It includes all children up to the age of 14, and all children between 15 and 25 if they are students (ea==6) */

gen nezaopb = 0 
label variable nezaopb "Dummy variable. Equals 1 if the person is not older than 15 years or 26 years and a student."
replace nezaopb = 1 if (vek<15) | (vek<26 & ea==6) //ea=6 means that the person is a student (daily study)

/*
WHAT SHOULD BEN UNIT FOR CHILD ALLOWANCE CONSIST OF?

- What is a "ben unit" for child allowance purposes?
	- Eligibility fora  child allowance is calculated based on income of a "family" - what is family?
	Zkon o sttn sociln podpoe,  7 (1-2): Za rodinu se pro ely tohoto zkona povauje, nen-li dle stanoveno jinak, oprvnn osoba a spolen s n posuzovan osoby. 
	Spolen posuzovanmi osobami jsou:
	a) nezaopaten dti ( 11), 
	b) nezaopaten dti ( 11) a rodie tchto dt (za rodie se povauj i osoby, jim byly nezaopaten dti sveny do pe nahrazujc pi rodi na zklad rozhodnut pslunho orgnu, manel, partner31a) rodie nebo uveden osoby, vdovec nebo vdova po rodii nebo uveden osob a druh (druka) rodie nebo uveden osoby), 
	c) manel, partnei31a) nebo druh a druka, nejde-li o rodie posuzovan podle psmene b), 
	d) nezaopaten dti, jejich rodie, pokud jsou nezaopatenmi dtmi a jsou osaml, a rodie [psmeno b)] tchto rodi, pokud s oprvnnou osobou spolu trvale ij a spolen uhrazuj nklady na sv poteby.7) 
	Spolen posuzovanmi osobami jsou i osoby, kter se pechodn z dvod studia, ze zdravotnch i pracovnch dvod zdruj mimo msto trvalho pobytu. 
	
	- opravnena osoba pro pridavky na deti je vzdy dite -> tedy i otec ditete, ktery v domacnosti nezije, muze spadat do "rodiny" a jeho prijem se muze posuzovat pro narok na pridavky... 
	- pokud ale napr otec ditete s rodinou vice jak 3 mesice nezije, muze matka pozadat o jeho vylouceni z okruhu spolecne posuzovanych osob ( 7 odstavec 7):
		Krajsk poboka adu prce me pi rozhodovn o dvkch v ppadech, kdy osoby uveden v odstavci 3 psm. a) a c) spolu nejmn po dobu t msc prokazateln neij, rozhodnout, e se neposuzuj jako osoby spolen posuzovan, nebo jde-li o pspvek na bydlen v ppadech, kdy nkter ze spolen posuzovanch osob nejmn po dobu t msc prokazateln byt neuv, rozhodnout, e se k n pi posouzen nroku na pspvek na bydlen a jeho vi nepihl, i kdy je v byt hlena k trvalmu pobytu.

	- assume that if a family member does not live in the HH (we dont see him/her in the data), the family will ask to exclude him/her from the "family" for purposes of child allowance
	=> "ben unit" consists of all nezaop children, their parents (including spouse of a parent etc.), their spouses (if they live in the HH), their children, and grandparents of nezaop children (but only if parents are themselves nezaop children, and if grandparents live in hte household)


Our goal is to have all "nezaopb" children, their parents, their spouses, and their children, and their grandparents (but only if parents are themselves nezaop children) in one ben unit.

NEZAOP CHILD IS A CENTRAL MEMBER OF BEN UNIT - distinguish several options:

I.  	NEZAOP CHILD HAS vztah==1 (head of HH) - 30 heads being nezaop child, and 22 of these are single person HHs
II. 	NEZAOP CHILD HAS vztah==2 (spouse of head) - 19 spouses of head being nezaop child
III. 	NEZAOP CHILD HAS vztah==3 (child of head) - 4,267 children of head are nezaop children
IV. 	NEZAOP CHILD HAS vztah==4 (sons/daughters in law of head) - no such individual in the data
V.  	NEZAOP CHILD HAS vztah==5 (grandchild of head) - 117 grandchildren of head being nezaop child
VI. 	NEZAOP CHILD HAS vztah==6 (parents or parents in law of head) - 2 individuals being a parent of head & nezaop child (mistake in the data!)
VII. 	NEZAOP CHILD HAS vztah==7 (sibling of head) - 8 siblings of head being nezaop child
VIII.	NEZAOP CHILD HAS vztah==8 (other) - 23 other hh members being nezaop child

ASSUMPTIONS:
- assume that if head of HH does not have a spouse (no person with vztah==2), the people with vztah==6 are his parents (and not parents in law) (OR also assume, there should be only one or two people with vztah==6, not more?)
	- if the spouse of head is present, there is no way to determine whether individuals with vztah==6 are parents of head or parents of spouse (do not allocate them to each of them in this case)
- assume that if spouse of head is a parent, the children of head (vztah==3) are also children of head's spouse (OR do we need to also assume that both head and spouse are married? OR do we want to assume that if spouse is married and has children in HH, children of head are hers?)
- assume that if there is exactly one married nezaop child (son/daughter) and exactly one married with vztah=4 (son-in-law/daughter-in-law), they are married to each other
	- if there is more than one of either (married son/daughter or married son/daughter in law) in the household, we do not put them into one ben unit
- assume that if there is exactly one son/daughter who is parent, the grandchildren of the head are his children
- assume that if there is exactly one son/daughter who is parent and there is exactly one son/daughter in law who is a parent, the grandchildren of the head belong to this couple (therefore to the son/daughter in law as well)
- assume that if head and his spouse are both married, spouse is a grandparent of head's grandchildren (gradnchidlren of head are hers gradnchidlren as well)

Create the ben units consisting of all nezaop chidlren in the data and their corresponding family memebers.
LEFT THE OTHER INDIVIDUALS IN THE DATA UNASSIGNED - it does not really matter whether they are in some ben unit or not, because only units that have nezaop children in them are going to be used in calculation of child allowance (and these individuals are all adults).

 */	
 

**************** I. NEZAOP CHILD HAS vztah==1 (head of HH) ****************
* dummy for head being a nezaop child
gen head_nezaop = (vztah == 1 & nezaopb==1)
by domac: egen head_nezaophh = total(head_nezaop)
label variable head_nezaophh "Dummy for head of household being a nezaop child"

* (1) ADDING HEAD OF HH, HEAD'S SPOUSE AND CHILDREN TO A TAX UNIT
* no need to check for any conditions (no matter whether spouse of head is married to him or not, they belong to the ben unit, also all children of head belong there)
replace benunit = domacstr+string(nextidb) 	if head_nezaophh==1 & assignedb==0 & (head_nezaop==1 | vztah==2 | (vztah==3 & nezaopb==1))
replace assignedb = assignedb+1 			if head_nezaophh==1 & assignedb==0 & (head_nezaop==1 | vztah==2 | (vztah==3 & nezaopb==1))

* (2) ADDING HEAD'S PARENTS
* but we want to make sure that vztah==6 indeed are his parents, and not parents in law
* assume that if head of HH does not have a spouse, the people with vztah==6 are his parents (and not parent sin law)
replace benunit = domacstr+string(nextidb) 	if head_nezaophh==1 & assignedb==0 & spousehh==0 & (vztah==6)
replace assignedb = assignedb+1 			if head_nezaophh==1 & assignedb==0 & spousehh==0 & (vztah==6)
increaseidb


**************** II. NEZAOP CHILD HAS vztah==2 (spouse of head) ****************
* dummy for spouse of head being a nezaop child
gen headspouse_nezaop = (nezaopb==1 & vztah==2)
by domac: egen headspouse_nezaophh = total(headspouse_nezaop)
label variable headspouse_nezaophh "Dummy for spouse of head being a nezaop child"

* (1) ADDING HEAD'S SPOUSE AND HEAD OF HH TO A BEN UNIT
replace benunit = domacstr+string(nextidb) 	if headspouse_nezaophh==1 & assignedb==0 & (vztah==1 | vztah==2)
replace assignedb = assignedb+1 			if headspouse_nezaophh==1 & assignedb==0 & (vztah==1 | vztah==2)

* (2) ADDING SPOUSE'S CHILDREN
* assume that if spouse of head is a parent, the children of head (vztah==3) are also children of head's spouse
replace benunit = domacstr+string(nextidb) 	if head_nezaophh==1 & assignedb==0 & spouseparent==1 & (vztah==3 & nezaopb==1)
replace assignedb = assignedb+1 			if head_nezaophh==1 & assignedb==0 & spouseparent==1 & (vztah==3 & nezaopb==1)
increaseidb

* (3) DO NOT ADD SPOUSE'S PARENTS - no way to tell whether they are her parents or head's parents
* if the spouse of head is present, there is no way to determine whether individuals with vztah==6 are parents of head or parents of spouse
 
	
**************** III. NEZAOP CHILD HAS vztah==3 (child of head) ****************
* dummy for child of head being a nezaop child
gen headchild_nezaop = (nezaopb==1 & vztah==3)
by domac: egen headchild_nezaophh = total(headchild_nezaop)
label variable headchild_nezaophh "Number of children of head which are nezaop children in the HH."

* (1) ADDING ALL NEZAOP CHILDREN AND THEIR PARENTS (household head) TO A BEN UNIT
replace benunit = domacstr+string(nextidb) 	if headchild_nezaophh>0 & (vztah==1 | (vztah==3 & nezaopb==1))
replace assignedb = assignedb+1 			if headchild_nezaophh>0 & (vztah==1 | (vztah==3 & nezaopb==1))

* (2) ADDING THE OTHER CHILDREN'S PARENT (spouse of head) TO A BEN UNIT
* assume that if spouse of head is a parent, the children of head (vztah==3) are also children of head's spouse
replace benunit = domacstr+string(nextidb) 	if headchild_nezaophh>0 & spouseparent==1 & (vztah==2)
replace assignedb = assignedb+1 			if headchild_nezaophh>0 & spouseparent==1 & (vztah==2)

* (3) ADDING CHILDREN'S SPOUSE AND CHILDREN'S CHILDREN TO THE BEN UNIT
//(i) When there is EXACTLY one nezaop son/daughter and exactly one son/daughter in law who are both married, we add the son/daughter in law to the ben unit (son/daughter is already part of it)
* dummy for married nezaop sons/daughters
gen sondaughter_nezaopmarried = 1 if vztah == 3 & stav == 2 & nezaopb==1
by domac: egen sondaughter_nezaopmarriedhh = count(sondaughter_nezaopmarried)
label variable sondaughter_nezaopmarriedhh "Number of nezaop sons/daughters of the household head who are married"

replace benunit = domacstr+string(nextidb) 	if headchild_nezaophh>0 & assignedb==0 & (sondaughter_nezaopmarriedhh==1 & sondaughterILmarriedhh==1) & sondaughterILmarried==1
replace assignedb = assignedb+1 			if headchild_nezaophh>0 & assignedb==0 & (sondaughter_nezaopmarriedhh==1 & sondaughterILmarriedhh==1) & sondaughterILmarried==1

//(ii) When there is exactly one nezaop son/daughter who is parent, we add the grandchildren of the head to his/her ben unit (assume they are his chidlren)
* dummy for nezaop sons/daughters who are parents
gen sondaughter_nezaopparent = 1 if vztah == 3 & rodic == 1 & nezaopb==1
by domac: egen sondaughter_nezaopparenthh = count(sondaughter_nezaopparent)
label variable sondaughter_nezaopparenthh "Number of nezaop sons/daughters of the household head who have a child living in the household"

replace benunit = domacstr+string(nextidb) 	if  headchild_nezaophh>0 & assignedb==0 & sondaughter_nezaopparenthh==1 & (nezaopb==1 & vztah==5)
replace assignedb = assignedb+1 			if  headchild_nezaophh>0 & assignedb==0 & sondaughter_nezaopparenthh==1 & (nezaopb==1 & vztah==5)

* (4) ADDING CHILDREN'S GRANDPARENTS (parents of head)
* we should add nezaop children's grandparents (parents of head - vztah==6) to its ben unit if the parent of child (household head) is a nezaop child (wihtout a spouse) himself and he is single ( 7 (2d))
* it is not important whether the grandparents are married or not
* here we again work with the assumption that if head of HH does not have a spouse (no person with vztah==2), the people with vztah==6 are his parents (and not parent sin law), and therefore they are indeed grandparents of child
replace benunit = domacstr+string(nextidb) 	if headchild_nezaophh>0 & assignedb==0 & (spousehh==0 & head_nezaophh==1) & vztah==6 
replace assignedb = assignedb+1 		 	if headchild_nezaophh>0 & assignedb==0 & (spousehh==0 & head_nezaophh==1) & vztah==6 
increaseidb


**************** IV. NEZAOP CHILD HAS vztah==4 (children-in-law of head) **************** 
* dummy for children in law of head being a nezaop child
gen headchildIL_nezaop = (nezaopb==1 & vztah==4)
by domac: egen headchildIL_nezaophh = total(headchildIL_nezaop)
label variable headchildIL_nezaophh "Number of children in law of head that are nezaop children in the HH."
// no observation - but anyway, create a code for them in case there are some observatoions e.g. in the SILC 2011

* (0) CREATE A BEN UNIT OF THESE NEZAOP CHIDLREN IN LAW
replace benunit = domacstr+string(nextidb) 	if headchildIL_nezaophh>0 & assignedb==0 & headchildIL_nezaop==1
replace assignedb = assignedb+1 			if headchildIL_nezaophh>0 & assignedb==0 & headchildIL_nezaop==1

* (1) ADDING THEIR SPOUSE (CHILDREN OF HEAD) TO A TAX UNIT
* again assume that if there is exactly one married nezaop child (son/daughter) and exactly one married with vztah=4 (son-in-law/daughter-in-law), they are married to each other* dummy for son/daughter in law who is a nezaop child being married
gen sondaughterIL_nezaopmarried = (vztah == 4 & stav == 2 & nezaopb==1)
by domac: egen sondaughterIL_nezaopmarriedhh = total(sondaughter_nezaopmarried)
label variable sondaughterIL_nezaopmarriedhh "Number of nezaop sons/daughters in law of the household head who are married"

replace benunit = domacstr+string(nextidb) 	if headchildIL_nezaophh>0 & assignedb==0 & sondaughterIL_nezaopmarriedhh==1 & sondaughtermarriedhh==1 & vztah==3
replace assignedb = assignedb+1 			if headchildIL_nezaophh>0 & assignedb==0 & sondaughterIL_nezaopmarriedhh==1 & sondaughtermarriedhh==1 & vztah==3

* (2) ADDING THEIR CHIDLREN (GRANDCHILDREN OF HEAD) TO A TAX UNIT
* assume that if there is exactly one son/daughter who is parent and there is exactly one son/daughter in law who is a parent, the grandchildren of the head belong to this couple (and thus to the son/daughter in law)
* dummy for son/daughter in law who is a nezaop child being parent
gen sondaughterIL_nezaopparent = (vztah == 4 & stav == 2 & nezaopb==1)
by domac: egen sondaughterIL_nezaopparenthh = total(sondaughter_nezaopparent)
label variable sondaughterIL_nezaopparenthh "Number of nezaop sons/daughters in law of the household head who are parents"

replace benunit = domacstr+string(nextidb) 	if headchildIL_nezaophh>0 & assignedb==0 & sondaughterIL_nezaopparenthh==1 & sondaughterparenthh==1 & (vztah==5 & nezaopb==1)
replace assignedb = assignedb+1 			if headchildIL_nezaophh>0 & assignedb==0 & sondaughterIL_nezaopparenthh==1 & sondaughterparenthh==1 & (vztah==5 & nezaopb==1)
increaseidb



**************** V. NEZAOP CHILD HAS vztah==5 (grandchild of head) **************** 
* dummy for grandchild of head being a nezaop child
gen headgrandch_nezaop = (nezaopb==1 & vztah==5)
by domac: egen headgrandch_nezaophh = total(headgrandch_nezaop)
label variable headgrandch_nezaophh "Number of grandchildren of head that are nezaop children in the HH."

* (0) CREATE A BEN UNIT OF THESE NEZAOP GRANDCHIDLREN
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & headgrandch_nezaop==1
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & headgrandch_nezaop==1

* (1) ADDING GRANDCHILDREN'S PARENTS (CHILDREN AND CHILDREN-IN-LAW OF HEAD) TO A TAX UNIT
* again assume that if there is exactly one son/daughter who is parent, the grandchildren of the head are his children
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & sondaughterparenthh==1 & (vztah==3)
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & sondaughterparenthh==1 & (vztah==3)

* again assume that if there is exactly one son/daughter who is parent and there is exactly one son/daughter in law who is a parent, the grandchildren of the head belong to this couple (therefore to the son/daughter in law as well)
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & sondaughterparenthh==1 & sondaughterILparenthh==1 & (vztah==4)
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & sondaughterparenthh==1 & sondaughterILparenthh==1 & (vztah==4)

* (2) ADDING GRANDCHILDREN'S GRANDPARENTS (HEAD OF HH AND HIS SPOUSE) TO A TAX UNIT
* (a) if there is no parent of a nezaop child (no child of head and no child in law of head in the HH), we add grandparents of a child to his ben unit
* dummy for no son/daughhter and no son/daughter in law of head in the family (therefore dummy for grandchild having no parent in a family)
by domac: egen sondaughhh = total(vztah==3)
by domac: egen sondaughILhh = total(vztah==4)
gen nosondaughnosondaughILhh = 1 if (sondaughhh==0 & sondaughILhh==0)
label variable nosondaughnosondaughILhh "Dummy for no son/daughter and no son/daughter in law of head in the HH"

* if there is no parent of a nezaop child, add head of HH to the ben unit together with his/her grandchild
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & nosondaughnosondaughILhh==1 & (vztah==1)
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & nosondaughnosondaughILhh==1 & (vztah==1)
* assume that if head and spouse are both married, head's spouse is a grandparent of head's grandchildren as well, and thus add her to the ben unit
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & nosondaughnosondaughILhh==1 & spousehh==2 & (vztah==2)
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & nosondaughnosondaughILhh==1 & spousehh==2 & (vztah==2)

* (b) if the parent of nezaop grandchildren (child of head) is present (and we can identify him - there is only one child of head who is a parent) 
* and he is single (there is no son/daughter in law) and he is himself a nezaop child (child of head is a nezaop child)
* we also add the children's grandparents (head of HH and his spouse) to the ben unit
* dummy for child of head being parent & being nezaop child himself 
gen headchildparentnezaop = (vztah==3 & rodic==1 & nezaopb==1)
by domac: egen headchildparentnezaophh = total(headchildparentnezaop)
label variable headchildparentnezaophh "Number of children of head who are parents and nezaop children."

* adding head of hh to the ben unit is such a case (according to  7 (2d) - grandparents of nezaop child are in their ben unit if the parent is single and nezaop child himself)
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & headchildparentnezaophh==1 & sondaughILhh==0 & (vztah==1)
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & headchildparentnezaophh==1 & sondaughILhh==0 & (vztah==1)
* assume that if head and spouse are both married, head's spouse is a grandparent of head's grandchildren, and thus add her to the ben unit as well
replace benunit = domacstr+string(nextidb) 	if headgrandch_nezaophh>0 & assignedb==0 & headchildparentnezaophh==1 & sondaughILhh==0 & spousehh==2 & (vztah==2)
replace assignedb = assignedb+1 			if headgrandch_nezaophh>0 & assignedb==0 & headchildparentnezaophh==1 & sondaughILhh==0 & spousehh==2 & (vztah==2)
increaseidb


**************** VI. NEZAOP CHILD HAS vztah==6 (parent or parent in law of head) **************** 
* dummy for parent (in law) of head being a nezaop child
gen headparent_nezaop = (nezaopb==1 & vztah==6)
by domac: egen headparent_nezaophh = total(headparent_nezaop)
label variable headparent_nezaophh "Number of parents of head that are nezaop children in the HH."

* I dont think it makes sence for parents of head to be a nezaop child (there is one HH with two individuals aged 4 and 6 with vztah==6 (this is clearly a mistake as the age of head is 42) - domac 520230181
* I dont work with this option


**************** VII. NEZAOP CHILD HAS vztah==7 (sibling of head) ***************  
* dummy for sibling of head being a nezaop child
gen headsibl_nezaop = (nezaopb==1 & vztah==7)
by domac: egen headsibl_nezaophh = total(headsibl_nezaop)
label variable headsibl_nezaophh "Number of siblings of head that are nezaop children in the HH."

* (0) CREATE A BEN UNIT OF THESE NEZAOP SIBLINGS
replace benunit = domacstr+string(nextidb) 	if headsibl_nezaophh>0 & assignedb==0 & headsibl_nezaop==1
replace assignedb = assignedb+1 			if headsibl_nezaophh>0 & assignedb==0 & headsibl_nezaop==1

* (1) ADD NEZAOP SIBLINGS' SIBLINGS TO THE BEN UNIT (head of hh)
* only if the head is nezaop himself, he can be added to the ben unit with his siblings
replace benunit = domacstr+string(nextidb) 	if headsibl_nezaophh>0 & assignedb==0 & head_nezaop==1 
replace assignedb = assignedb+1 			if headsibl_nezaophh>0 & assignedb==0 & head_nezaop==1

* (2) ADD NEZAOP SIBLINGS' PARENTS TO THE BEN UNIT 
* these are parents of head of hh, but we cannot distinguish between parents and parents in law of head in the data
* assume again that if head of HH does not have a spouse, the people with vztah==6 are his parents (and thus parents of his siblings), not his parents in law
replace benunit = domacstr+string(nextidb) 	if headsibl_nezaophh>0 & assignedb==0 & spousehh==0 & vztah==6
replace assignedb = assignedb+1 			if headsibl_nezaophh>0 & assignedb==0 & spousehh==0 & vztah==6
increaseidb


**************** VIII. NEZAOP CHILD HAS vztah==8 (other) ***************  
* dummy for other faily members being a nezaop child
gen other_nezaop = (nezaopb==1 & vztah==8)
by domac: egen other_nezaophh = total(other_nezaop)
label variable other_nezaophh "Number of other HH members that are nezaop children in the HH."

* (0) CREATE A BEN UNIT OF THESE OTHER NEZAOP CHILDREN
replace benunit = domacstr+string(nextidb) 	if other_nezaophh>0 & assignedb==0 & other_nezaop==1
replace assignedb = assignedb+1 			if other_nezaophh>0 & assignedb==0 & other_nezaop==1
increaseidb

* for now, do not assign any other family members to them (we  cannot tell who their parents are)

**************** THE UNASSIGNED PEOPLE ARE ASIGNED TO BENUNIT==0 (and in the calculation of child allowance they are not used) ****************
tabulate assignedb
tabulate assignedb if nezaopb==1 // the two unassigned nezaop children are those with vztah==6 (mistake in the data - do something about it?)

replace benunit = "0" if assignedb==0

**************** HEAD OF BEN UNIT **************** 
* head of ben units - the member with the highest income
* I follow the way head of tax unit was created (using the dummy for household head)
gsort benunit -ginc_i
by benunit: egen benhead=rank(-(ginc_i+householdhead)) if benunit!="0" ,unique  //benunit = "0"... those unassigned to ben units
replace benhead = 0 if benhead > 1 //if not the highest income in the tax unit, replace with 0
label variable benhead "Dummy, equal to 1 if the person is head of a ben unit, 0 otherwise"

* check that each ben unit has a benhead (OK)
bysort benunit: egen benhead_hh = total(benhead)
tab  benhead_hh if benunit!="0"

***** drop the variables that are no longer necessary
drop marriedhead marriedspouse marriedheadhh marriedspousehh sondaughter sondaughterparent nextid spouse spousehh spouseparent sondaughterhh sondaughterparenthh sondaughtermarried sondaughtermarriedhh sondaughtermarriedparent sondaughtermarriedparenthh sondaughterIL sondaughterILhh sondaughterILparent sondaughterILparenthh sondaughterILmarried sondaughterILmarriedhh sondaughterILmarriedparent sondaughterILmarriedparenthh parentmarried parentmarriedhh IDtmp numberofunassigned  richesttaxheadtaxunit richesttaxheadtaxunithh richesttaxheadtaxunithhstr domacstr members membersassignedold assigned
drop nextidb membersassignedbold membersassignedb assignedb householdhead
drop head_nezaop head_nezaophh headspouse_nezaop headspouse_nezaophh headchild_nezaop headchild_nezaophh sondaughter_nezaopmarried sondaughter_nezaopmarriedhh sondaughter_nezaopparent sondaughter_nezaopparenthh headchildIL_nezaop headchildIL_nezaophh sondaughterIL_nezaopmarried sondaughterIL_nezaopmarriedhh sondaughterIL_nezaopparent sondaughterIL_nezaopparenthh headgrandch_nezaop headgrandch_nezaophh sondaughhh sondaughILhh nosondaughnosondaughILhh headchildparentnezaop headchildparentnezaophh headparent_nezaop headparent_nezaophh headsibl_nezaop headsibl_nezaophh other_nezaop other_nezaophh 




*======================* WAGE IMPUTATION *======================*
/*
ASSUMPTIONS
	- those not working would start working as employees
	- sample is defined as a population of potential workers (in productive age and not full-time students and not having serious health problem)  
	- for wage imputation, we use working employees' wages only (not self-employed working income)
	- we also allow the non-working to either receive wage in formal work only - use income concepts as defined in dataprocess: gincwf "Gross income from formal work" and gincwi	"Gross income from informal work"
QUESTION
	- using also part time wage income?? (for imputation of full-time wages?)
	*/
	
*********** SAMPLE FOR WAGE IMPUTATION *********** 
* define the population of potential workers (by age, and by not being a student, and not having the most serious health problem)
g potlfp = 0
replace potlfp = 1 if (pohl==1 & vek>=18 & vek<=60 & ea~=6 & z_problem~=4)
replace potlfp = 1 if (pohl==2 & vek>=18 & vek<=57 & ea~=6 & z_problem~=4)

* household with some potential labor force participants
bysort domac: egen hhpotlfp = total(potlfp>0)
replace hhpotlfp = 1 if hhpotlfp>0

* dummy for the non-working potential workers (whom we will impute wages) 
gen p = 0 if potlfp==1 & (hp_hzam==0 & hp_podn==0 & hp_vzam==0 & hp_vcin==0)
* dummy for the working employees (whom we will use for wage imputation) - only main job and formal work (both part and full time employees)
replace p = 1 if potlfp==1 & (mes_zam>0 & hp_hzam>0 & odprac>0 & infw==0)

* define households used in the analysis - households without pensioners or households with some pensioner, but with at least one potential earner
capture drop pensioners pens_hh
bysort domac: egen pensioners = total((pohl==1 & vek>=61 & ea==7) | (pohl==2 & vek>=58 & ea==7))
gen pens_hh = (pensioners>0)
gen hhnonpen = (pens_hh==0 | hhpotlfp==1)


*********** HOURLY WAGE based on employees' main income *********** 
*** monthly income from main employment
gen hp_hzamm = hp_hzam / mes_zam 		if p==1
* hourly wage
gen mzda = hp_hzamm / (odprac*4.345)	if p==1	 	/* odprac - pocet hod za tyden */
gen lmzda = ln(mzda)					if p==1

*********** RHS VARIABLES ***********
* education - categories
gen zakl = (vzd<3)
gen SS = (vzd>2 & vzd<7)
gen VS = (vzd>6)

* age 
gen vek2 = vek^2

* children dummies
gen d_2d 	=(d_2>=1)
gen d3_5d 	=(d3_5>=1)
gen d6_9d 	=(d6_9>=1)
gen d10_15d	=(d10_15>=1)
gen d16_d 	=(d16_>=1)

* nationality - CR or other 
gen 	CR = 1 if narodnost==1
replace CR = 0 if (narodnost!=1 & narodnost!=0)  /*narodnost==0 - chybejici pozorovani*/

* kraj - dummy
gen Prh	 = (domac < 210000000)
gen Strc = (domac >= 210000000 & domac < 310000000)
gen Jihc = (domac >= 310000000 & domac < 320000000)
gen Plz  = (domac >= 320000000 & domac < 410000000)
gen Karl = (domac >= 410000000 & domac < 420000000)
gen Ust  = (domac >= 420000000 & domac < 510000000)
gen Lib  = (domac >= 510000000 & domac < 520000000)
gen Kral = (domac >= 520000000 & domac < 530000000)
gen Pard = (domac >= 530000000 & domac < 620000000)
gen Jihm = (domac >= 620000000 & domac < 710000000)
gen Olom = (domac >= 710000000 & domac < 720000000)
gen Zlin = (domac >= 720000000 & domac < 810000000)
gen Mors = (domac >= 810000000)

* type of HH (dummy for domacnosti jednotlivcu s detmi nebo bez - samozivitele)
gen dom1 = (dom_eu==1 | dom_eu==2 | dom_eu==9)

* typ (velikost) obce (typ==1 je hl.m. Praha)
gen mesto = (typ == 2)
gen obec = (typ == 3) /* vynechana kategorie je vesnice, Praha je v dummy Prh*/

* married
gen mar = (stav==2)


*********** WAGE EQUATION - HECKMAN CORRECTION ***********
**** HECKMAN
* men 
heckman lmzda mar zdrav_stav vek vek2 SS VS Prh Strc Jihc Plz Karl Ust Lib Kral Pard Jihm Olom Zlin CR mesto obec if pohl==1, select(p = d_2d d3_5d d6_9d d10_15d d16_d dom1 mar zdrav_stav vek vek2 SS VS Prh Strc Jihc Plz Karl Ust Lib Kral Pard Jihm Olom Zlin CR mesto obec) twostep
predict lmzda_pr if (p==1 | p==0) & pohl==1, xb
* women
heckman lmzda mar zdrav_stav vek vek2 SS VS Prh Strc Jihc Plz Karl Ust Lib Kral Pard Jihm Olom Zlin CR mesto obec if pohl==2, select(p = d_2d d3_5d d6_9d d10_15d d16_d dom1 mar zdrav_stav vek vek2 SS VS Prh Strc Jihc Plz Karl Ust Lib Kral Pard Jihm Olom Zlin CR mesto obec) twostep
predict lmzda_pr2 if (p==1 | p==0) & pohl==2, xb
replace lmzda_pr = lmzda_pr2 if pohl==2
drop lmzda_pr2


*** predicted wages - check
sum lmzda lmzda_pr if  p==1
twoway (scatter lmzda lmzda_pr if p==1, xlab(3(1)8) ylab(3(1)8) nodraw)

* predikovana rocni mzda pro plny a castecny uvazek
gen mzda_f = exp(lmzda_pr) * 40 * 4.345 * 12
gen mzda_p = exp(lmzda_pr) * 20 * 4.345 * 12

twoway histogram mzda_f if p==0, fintensity(inten80) fcolor(edkblue) lcolor(edkblue) legend(label(1 "non-working")) start(10000) width(1000)  || histogram mzda_f if p==1,  barwidth(500) legend(label(2 "working")) start(10000) width(1000) nodraw 

drop lmzda_pr lmzda mzda hp_hzamm

*********** REPLACE WAGE WITH PREDICTED (for non-working) FOR FULL-TIME and PART-TIME -> in etbchars ***********

*********** HOUSEHOLD CHARACTERISTICS ***********************
* Dummies for number of children
* Indicators of (potential) labor supply at HH level
	
	* number of children
	gen deti3 = deti
	replace deti3 = 3 if deti>3
	label var deti3 "Number of children"
	label define deti 0 "0" 1 "1" 2 "2" 3 "3 and more", replace
	label values deti3 deti
	
	* dummy for number of children
	gen detin0 = (deti==0)
	gen detin1 = (deti==1)
	gen detin2 = (deti==2)
	gen detin3 = (deti>=3)
	
	
	* potential labor supply of head and spouse - many results are presented only for people and households that can realistically work
	* defined as prime-aged individuals (18-60), who are not students and dont have a serious health problem
	bysort domac: egen potlfp_p = total(vztah==1 & vek>=18 & vek<=60 & ea!=6 & z_problem!=4)
	bysort domac: egen potlfp_m = total(vztah==2 & vek>=18 & vek<=60 & ea!=6 & z_problem!=4)
	gen potlfp_pm = (potlfp_p*potlfp_m)
	
	* presence of spouse in the HH
	bysort domac: egen pres_m = total(vztah==2)
	* age of spouse
	replace vek_m = . if pres_m==0 //replace age of spouse by . if spouse is not in the HH
		
	* wokring status of head and spouse
	bysort domac: egen work_p = total(vztah==1 & ea<=4)
	bysort domac: egen work_m = total(vztah==2 & ea<=4) if pres_m==1

	gen work_hh 	= 0 if work_p==0 & work_m==0
	replace work_hh = 1 if work_p==1 & work_m==0
	replace work_hh = 2 if work_p==0 & work_m==1
	replace work_hh = 3 if work_p==1 & work_m==1
	
	label var potlfp_p 	"Dummy for head of household being potential labor force participant"
	label var potlfp_m 	"Dummy for spouse of head of household being potential labor force participant"
	label var work_p 	"Indicator for head of household working"
	label var work_m 	"Indicator for spouse of head of household working"
	label var work_hh 	"Working status of a HH"
	label define work 0 "neither spouse working" 1 "head working, spouse not" 2 "spouse working, head not" 3 "both spouses working", replace
	label values work_hh work

	* HH income types - by type of income
	capture drop hhinc_type inc_type number
	capture label drop hhinc_type inc_type 
	gen		hhinc_type = 1 if vztah==1 & hhnonpen==1 & (hhginc_w>inclb & hhginc_b==0)  //all HHs with positive work income
	replace	hhinc_type = 2 if vztah==1 & hhnonpen==1 & (hhginc_w==0 & hhginc_b>inclb)	 //all HHs with positive business income 
	replace hhinc_type = 3 if vztah==1 & hhnonpen==1 & (hhginc_w>inclb & hhginc_b>inclb) //all HHs with positive work & business income
	replace hhinc_type = 4 if vztah==1 & hhnonpen==1 & (hhginc_w==0 & hhginc_b==0) //all HHs with no positive income
	label define hhinc_type 1 "HHs with positive work income" 2 "HHs with positive business income" 3 "HHs with positive business and work income" 4 "HHs without income"
	label values hhinc_type hhinc_type
	
	* HH income types - by income/no income
	gen		hhinc_type2 = 1 if vztah==1 & hhnonpen==1 & (hhginc_w>inclb | hhginc_b>inclb)  //all HHs with positive income
	replace	hhinc_type2 = 2 if vztah==1 & hhnonpen==1 & (hhginc_w==0 & hhginc_b==0)	 //all HHs with positive business income 
	label define hhinc_type2 1 "HHs with positive earnings" 2 "HHs without earnings"
	label values hhinc_type2 hhinc_type2
	
	* individual income types
	gen		inc_type = 1 if potlfp==1 & (ginc_w>inclb & ginc_b==0) 	  //all individuals with positive work income
	replace	inc_type = 2 if potlfp==1 & (ginc_w==0 & ginc_b>inclb)	  //all individuals with positive business income 
	replace inc_type = 3 if potlfp==1 & (ginc_w>inclb & ginc_b>inclb) //all individuals with positive work & business income
	label define inc_type 1 "individuals with positive work income" 2 "individuals with positive business income" 3 "individuals with positive business and work income"
	label values inc_type inc_type

	
save taxben, replace 

*** OTHER USEFUL PERSONAL AND HH-LEVEL VARIABLES ****
* Female dummy
g dmy_female  = pohl==2 
label var dmy_female "Dummmy for gender = female"

* Mortgage interest - for the purposes of taking deduction (15.3-4)
	* Very limited information, but we need to deconstruct using deductions
	* Basic assumptions: 
	* a1) If the HH lives in the current dwelling for less than 10 years, the mortgage was for the purchase
	* a2) The value of the mortgage was 50% of the estimated value of the home
	* a3) The mortgage was takes when they moved in - this determines the interest
	* b1) If the hh lives there for more than 10 years, they took a mortgage to reconstruct
	* b2) The value of the mortgage is 20% of the estimated value (admittedly very crude)
	* b3) The mortgage was taken at a random date between 2000 and 2011 
	* c1) The interest rate is 4%
	* c2) The duration is 15 years
	
	* Imputatation: 
	* i) For each hh with a mortgage, set the mortgage value and start of the mortgage
	* Loop over taxheads: 
	* create the matrix of mortgage payments
	* extract the interest payment as a fn of the length
	g dmy_hypo = hypo==1
	g mortg_payment = 0
	g mortg_frac = mortg_payment/cp_prij
	g mortg_interest = 0 
	
	label var dmy_hypo 			"Dummy = 1 if hh has mortgage"
	label var mortg_payment  	"Mortgage payment (imputed)"
	label var mortg_frac 		"Mortgage payment as a fraction of net income"
	label var mortg_interest 	"Mortgage interest (imputed)"
	
	g mortg_value 		= 0.50*trz_cena if hypo==1 & taxhead==1 & bydli_od> 1999
	replace mortg_value = 0.20*trz_cena if hypo==1 & taxhead==1 & bydli_od<=1999
	label var mortg_value "Value of the mortgage (when taken)"
	g mortg_dur = 2011 - bydli_od + 1 if hypo==1 & taxhead==1 & bydli_od> 1999
	replace mortg_dur = 1+ int((12-1+1)*runiform()) if hypo==1 & taxhead==1 & bydli_od<=1999
	label var mortg_dur "Duration of the mortgage (years since taken)"
	gsort -dmy_hypo -taxhead
	* set the variable over which to loop: 
	g loopn = _n 
	* set the number of loops: 
	sum taxhead if dmy_hypo==1 & taxhead ==1
	local NL = r(N) 
	forvalues i = 1 (1) `NL' {
		* for each hh, must set the inputs into the mortgage payment matrix as scalars
		sum mortg_value if loopn==`i'
		local pv = r(sum)
		sum mortg_dur if loopn==`i'
		local mortg_dur = r(sum)
		* now generate the mortgage payment matrix, save it as MTG
		payper, pv(`pv') nper(15) freq(y) rate(0.04)
		* extract the interest payment in the current year payment
		* take the cap into account
		scalar int_payment = el(r(matpay),`mortg_dur',3)
		replace mortg_interest = scalar(int_payment) if loopn==`i'
		* for checking, extract the mortgage payment - if it is not too high compared with income
		replace mortg_payment = r(PMT) if loopn==`i'
		replace mortg_frac = mortg_payment/cp_prij
	}
	*
capture	drop _merge
save taxben, replace //output -> processed data ready for descriptive work


*======================* TAKE-UP ANALYSIS *======================*
* for housing benefit and aid in material need
* sample of eligible individuals who are heads of household
* analysis at the level of household
* generate dummy for take-up (1 if reported amount is positive)

capture mkdir output_z
cd output_z
use taxben_z_fulltakeup, clear //output dataset from running the model for "z" system with 100% takeup (because take up is modelled using this dataset)
* for birth grant, the analysis cannot be conducted, only 17 observations eligible in the sample

capture mkdir logs_z
cd logs_z
capture log close
log using takeup_z, replace

***** generate dummies for positive reported benefits (sample of people with positive assigned benefits)
gen hous_benpos_c = (hous_benhh_c>0) if hous_benhh_z>0 & vztah==1 & hhnonpen==1
gen mat_needpos_c = (mat_needhh_c>0) if mat_needhh_z>0 & vztah==1 & hhnonpen==1

sum domac hous_benpos_c mat_needpos_c

	* material need regression - problem with variables predicting take-up perfectly
	* no people reporting take-up among VS, Plz
	*sum vek vek2 SS VS mar zdrav1-zdrav5 d_2d d3_5d d6_9d d10_15d d16_d dom1 dom_eu mesto obec Prh Strc Jihc Plz Karl Ust Lib Kral Pard Jihm Olom Zlin if mat_needhh_z>0 & benhead==1 & mat_needpos_c==1

quietly tabulate zdrav_stav, gen(zdrav)
***** probit regressions
probit hous_benpos_c hous_benhh_z vek vek2 SS VS mar zdrav1-zdrav5 d_2d d3_5d d6_9d d10_15d d16_d dom1 dom_eu mesto obec Prh Strc Jihc Plz Karl Ust Lib Kral Pard Jihm Olom Zlin
capture drop probtakeup_hous_ben
predict probtakeup_hous_ben if hous_benhh_z>0 & vztah==1 & hhnonpen==1
probit mat_needpos_c mat_needhh_z vek vek2 SS mar zdrav1-zdrav5 d_2d d3_5d d6_9d d10_15d d16_d dom1 dom_eu mesto obec Prh Strc Jihc Karl Ust Lib Kral Pard Jihm Olom Zlin
capture drop probtakeup_mat_need
predict probtakeup_mat_need if mat_needhh_z>0 & vztah==1 & hhnonpen==1

sum hous_benpos_c probtakeup_hous_ben mat_needpos_c probtakeup_mat_need

*** determine takeup 0 or 1: generate cumulative sum of simulated benefits of households (first those with highest takeup) up until the point where sum equals to external statistics - there takeup switches to 0
local bentypes "hous_ben mat_need" 
foreach x of local bentypes {
* first sort by probability of take up (descending order)
gsort -probtakeup_`x'
* generate weighted amount of benefits
gen we_`x'hh_z			= `x'hh_z*(round(pkoef))
* generate cumulative sum of benefit
gen exp_`x'_sim 	= we_`x'hh_z[1] if vztah==1 & hhnonpen==1
forvalues i = 1 (1) 1000 {
replace exp_`x'_sim 	= exp_`x'_sim[`i'] + we_`x'hh_z[`i+1'] if vztah==1 & hhnonpen==1 & _n>`i' //cumulative sum of expenditures on housing benefit
}
}
* find cutoff, where the cumulative sum of simulated expneditures is higher thatn external statistics - takeup at household level
capture drop takeup_hous_ben takeup_mat_need
bysort domac: egen takeup_hous_ben = total(exp_hous_ben_sim<=5321000000 & vztah==1 & hhnonpen==1 & probtakeup_hous_ben!=.)
replace takeup_hous_ben = . if hous_benhh_z==0
bysort domac: egen takeup_mat_need = total(exp_mat_need_sim<=3882000000 & vztah==1 & hhnonpen==1 & probtakeup_mat_need!=.)
replace takeup_mat_need = . if mat_needhh_z==0

sum takeup_hous_ben takeup_mat_need if vztah==1 & hhnonpen==1

log close
cd ../..

keep domac osoba takeup_hous_ben takeup_mat_need

merge 1:1 domac osoba using taxben // merge with data that are created at the end of dataprocess (right before take-up analysis)

save taxben, replace //output -> processed data ready for descriptive work




