*** EMPIRICAL TAXBEN MODEL
*** MASTER DO-FILE THAT COMPUTES AND REPORTS EFFECTS OF A REFORM, OR SIMPLY A COMPARISON OF ANY TWO TAX REGIMES
*** The set-up: 
*** 1) Select the regimes "before the reform" (`t') and "after the reform (`u') 
*** 2) Runs the taxben (the computational parts, without the tables or graphs) for both regimes
*** 3) Merges the resulting datasets 
*** 4) Calculates the diffs
*** 5) Reports the results for the diffs

*** NOTATIONAL CONVENTIONS:
*** the diff variables have the same name as level variables, except the suffix is _`u'`t'
*** Eg. a change in ATR from regime 2 to regime 3: atr_3 - atr_2 = atr_32

capture clear matrix
clear
capture set more off
set memory 512m
capture program drop taxbenreform
program define taxbenreform
args u t 
	capture mkdir output_`u' 
	do etbdataprocess
	do etbcomputetax
	taxcompute `u' taxben taxben_`u'
	do etbcomputeben
	bencompute `u' taxben_`u' taxben_`u' 
	do etbchars
	taxbenchars `u'
	
	capture mkdir output_`t' 
	do etbcomputetax
	taxcompute `t' taxben taxben_`t'
	do etbcomputeben
	bencompute `t' taxben_`t' taxben_`t' 
	do etbchars
	taxbenchars `t'
	
	capture mkdir output_`u'_`t'
	do etbcompare
	reformcompare `u' `t'
	do etbtables
	taxbentables `u'_`t'
	do etbreformplots
	reformplots `u'_`t'
	do plotsczreform
	plotsczreform `u' `t'
	
end

**********************
*** RUN THE PROGRAM 
*** INPUT THE TWO TAX REGIMES
taxbenreform 5d 3

